@@ -3,6 +3,7 @@ from vectorcode.subcommands.drop import drop
 from vectorcode.subcommands.init import init
 from vectorcode.subcommands.ls import ls
 from vectorcode.subcommands.query import query
+from vectorcode.subcommands.update import update
 from vectorcode.subcommands.vectorise import vectorise
 
-__all__ = ["drop", "init", "query", "ls", "vectorise", "check"]
+__all__ = ["drop", "init", "query", "ls", "vectorise", "check", "update"]
